@@ -3,15 +3,14 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of a note in a scale
 
-our $VERSION = '0.0703';
-
-use Carp;
-use List::Util qw( first );
-use Moo;
-use Music::Note;
-use Music::Scales;
+our $VERSION = '0.0704';
 
 use strictures 2;
+use Carp qw(croak);
+use List::Util qw( first );
+use Moo;
+use Music::Note ();
+use Music::Scales qw(get_scale_notes);
 use namespace::clean;
 
 
@@ -171,7 +170,7 @@ Music::ScaleNote - Manipulate the position of a note in a scale
 
 =head1 VERSION
 
-version 0.0703
+version 0.0704
 
 =head1 SYNOPSIS
 
@@ -361,7 +360,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Gene Boggs.
+This software is copyright (c) 2022 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
